==> pdfbox-2.0.35-src.zip: pdfbox-2.0.35/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightDocument.java <==
/*****************************************************************************
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 ****************************************************************************/

package org.apache.pdfbox.preflight;

import java.io.IOException;
import java.util.Collection;

import org.apache.pdfbox.cos.COSDocument;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.preflight.ValidationResult.ValidationError;
import org.apache.pdfbox.preflight.exception.ValidationException;
import org.apache.pdfbox.preflight.utils.ContextHelper;

public class PreflightDocument extends PDDocument
{

    private ValidationResult result = new ValidationResult(true);

    private PreflightConfiguration config;

    private PreflightContext context;

    private final Format specification;

    /**
     * Create an empty preflight document and load the default configuration for the given format.
     * 
     * @param format the format used for validation
     * @throws IOException
     */
    public PreflightDocument(Format format) throws IOException
    {
        this(format, null);
    }

    /**
     * Create a preflight document based on the COSDocument and load the default configuration for the given format.
     * 
     * @param doc the underlying COSDocument
     * @param format the format used for validation
     */
    public PreflightDocument(COSDocument doc, Format format)
    {
        this(doc, format, null);
    }

    /**
     * Create an empty preflight document that will use the given configuration bean to process the validation. If the
     * configuration is null, a default configuration will be loaded using the given format.
     * 
     * @param format the format used for validation
     * @param cfg the configuration used for validation
     * @throws IOException
     */
    public PreflightDocument(Format format, PreflightConfiguration cfg) throws IOException
    {
        this(new COSDocument(), format, cfg);
    }

    /**
     * Create a preflight document based on the COSDocument that will use the given configuration bean to process the
     * validation. If the configuration is null, a default configuration will be loaded using the given format.
     * 
     * @param doc the underlying COSDocument
     * @param format the format used for validation
     * @param config the configuration used for validation
     */
    public PreflightDocument(COSDocument doc, Format format, PreflightConfiguration config)
    {
        super(doc);
        this.specification = format;
        this.config = config;
        if (this.config == null)
        {
            initConfiguration(format);
        }
    }

    private void initConfiguration(Format format)
    {
        switch (format)
        {
        default: // default is PDF/A1-b
            this.config = PreflightConfiguration.createPdfA1BConfiguration();
            break;
        }

    }

    public ValidationResult getResult()
    {
        return result;
    }

    public void setResult(ValidationResult result)
    {
        if (this.result != null)
        {
            this.result.mergeResult(result);
        }
        else if (result != null)
        {
            this.result = result;
        }
        else
        {
            this.result = new ValidationResult(true);
        }
    }

    public void addValidationError(ValidationError error)
    {
        if (error != null)
        {
            if (result == null)
            {
                this.result = new ValidationResult(error.isWarning());
            }
            this.result.addError(error);
        }
    }

    public PreflightContext getContext()
    {
        return this.context;
    }

    public void setContext(PreflightContext context)
    {
        this.context = context;
    }

    /**
     * Check that PDDocument is a valid file according to the format given during the object creation.
     * 
     * @throws ValidationException
     */
    public void validate() throws ValidationException
    {
        // force early class loading to check if people forgot to use --add-modules javax.xml.bind
        // on java 9 & 10, or to add jaxb-api on java 11 and later
        javax.xml.bind.DatatypeConverter.parseInt("0");
        context.setConfig(config);
        Collection<String> processes = config.getProcessNames();
        for (String name : processes)
        {
            ContextHelper.validateElement(context, name);
        }
    }

    /**
     * Returns the format which is used to validate the pdf document.
     * 
     * @return the format used for validation
     */
    public Format getSpecification()
    {
        return specification;
    }

}

==> pdfbox-3.0.6-src.zip: pdfbox-3.0.6/preflight/src/main/java/org/apache/pdfbox/preflight/PreflightDocument.java <==
/*****************************************************************************
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 ****************************************************************************/

package org.apache.pdfbox.preflight;

import java.util.Collection;
import java.util.Collections;
import java.util.List;

import org.apache.pdfbox.cos.COSDocument;
import org.apache.pdfbox.io.RandomAccessRead;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.preflight.ValidationResult.ValidationError;
import org.apache.pdfbox.preflight.exception.ValidationException;
import org.apache.pdfbox.preflight.utils.ContextHelper;

public class PreflightDocument extends PDDocument
{
    private final ValidationResult result = new ValidationResult(true);

    private final PreflightConfiguration config;

    private PreflightContext context;

    private final Format specification;

    /**
     * Create a preflight document based on the COSDocument and load the default configuration for the given format.
     * 
     * @param doc the underlying COSDocument
     * @param format the format used for validation
     */
    public PreflightDocument(COSDocument doc, Format format)
    {
        this(doc, format, null, null);
    }

    /**
     * Create a preflight document based on the COSDocument that will use the given configuration bean to process the
     * validation. If the configuration is null, a default configuration will be loaded using the given format.
     * 
     * @param doc the underlying COSDocument
     * @param format the format used for validation
     * @param config the configuration used for validation
     *
     * @deprecated use the 4 parameter constructor and pass the source.
     */
    @Deprecated
    public PreflightDocument(COSDocument doc, Format format, PreflightConfiguration config)
    {
        this(doc, format, config, null);
    }

    /**
     * Create a preflight document based on the COSDocument that will use the given configuration bean to process the
     * validation. If the configuration is null, a default configuration will be loaded using the given format.
     * 
     * @param doc the underlying COSDocument
     * @param format the format used for validation
     * @param config the configuration used for validation
     * @param source input representing the pdf
     */
    public PreflightDocument(COSDocument doc, Format format, PreflightConfiguration config, RandomAccessRead source)
    {
        super(doc, source);
        this.specification = format;
        // PDF/A1-b is default
        this.config = config == null ? PreflightConfiguration.createPdfA1BConfiguration() : config;
    }

    /**
     * Returns an unmodifiable list of all validation errors.
     * 
     * @return an unmodifiable list of all validation errors
     */
    public List<ValidationError> getValidationErrors()
    {
        return Collections.unmodifiableList(result.getErrorsList());
    }

    /**
     * Add a validation error.
     * 
     * @param error the validation error to be added
     */
    public void addValidationError(ValidationError error)
    {
        if (error != null)
        {
            this.result.addError(error);
        }
    }

    /**
     * Add a list of validation errors.
     * 
     * @param errorList the list of validation errors
     */
    public void addValidationErrors(List<ValidationError> errorList)
    {
        if (errorList != null)
        {
            this.result.addErrors(errorList);
        }
    }

    /**
     * Returns the associated preflight context. It is created after parsing the pdf.
     * 
     * @return the associated preflight context
     */
    public PreflightContext getContext()
    {
        return this.context;
    }

    /**
     * Set the preflight context for this document.
     * 
     * @param context the associated preflight context
     */
    public void setContext(PreflightContext context)
    {
        this.context = context;
    }

    /**
     * Check that PDDocument is a valid file according to the format given during the object creation.
     * 
     * @return the validation result
     * @throws ValidationException
     */
    public ValidationResult validate() throws ValidationException
    {
        context.setConfig(config);
        Collection<String> processes = config.getProcessNames();
        for (String name : processes)
        {
            ContextHelper.validateElement(context, name);
        }
        return result;
    }

    /**
     * Returns the format which is used to validate the pdf document.
     * 
     * @return the format used for validation
     */
    public Format getSpecification()
    {
        return specification;
    }

}
